@@ -149,8 +149,14 @@ def do_build(_project_name: str, _project_dir: str) -> None:
     Can we run commands under a virtual environment directly?
     """
     kwargs = {}
-    if os.path.isfile(".myenv"):
-        ret = subprocess.call(["venv-run", "make"], **kwargs)
+    if os.path.isfile(".myenv") and os.path.isfile("Makefile"):
+        ret = subprocess.call([
+            "venv-run",
+            "--venv",
+            ".venv/default",
+            "--",
+            "make",
+        ], **kwargs)
         return ret == 0
     if os.path.isfile("bootstrap"):
         ret = subprocess.call(["bootstrap"], **kwargs)
@@ -170,6 +176,13 @@ def do_pull(_project_name: str, _project_dir: str) -> int:
     return subprocess.call(args)
 
 
+def do_check_workflow_exists_for_makefile() -> Tuple[bool, str]:
+    if os.path.isfile("Makefile"):
+        if not os.path.isfile(".github/workflows/makefile.yml"):
+            return True, ""
+    return False, ""
+
+
 def do_grep(_project_name: str, project_dir: str) -> None:
     args = ['git', 'grep']
     if ConfigDebug.git_verbose:
